@@ -30,6 +30,7 @@
 #include "libglnx.h"
 
 #include "flatpak-builtins.h"
+#include "flatpak-repo-utils-private.h"
 #include "flatpak-utils-private.h"
 #include "parse-datetime.h"
 
@@ -129,7 +130,7 @@ static GVariant *
 new_bytearray (const guchar *data,
                gsize         len)
 {
-  gpointer data_copy = g_memdup (data, len);
+  gpointer data_copy = g_memdup2 (data, len);
   GVariant *ret = g_variant_new_from_data (G_VARIANT_TYPE ("ay"), data_copy,
                                            len, FALSE, g_free, data_copy);
 
@@ -719,7 +720,7 @@ flatpak_builtin_build_commit_from (int argc, char **argv, GCancellable *cancella
           {
             g_autoptr(GError) local_error = NULL;
             if (!rewrite_delta (src_repo, resolved_ref, dst_repo, commit_checksum, dst_commitv, from[j], &local_error))
-              g_debug ("Failed to copy delta: %s", local_error->message);
+              g_info ("Failed to copy delta: %s", local_error->message);
           }
       }
     }
@@ -738,7 +739,7 @@ flatpak_builtin_build_commit_from (int argc, char **argv, GCancellable *cancella
       if (opt_no_summary_index)
         flags |= FLATPAK_REPO_UPDATE_FLAG_DISABLE_INDEX;
 
-      g_debug ("Updating summary");
+      g_info ("Updating summary");
       if (!flatpak_repo_update (dst_repo, flags,
                                 (const char **) opt_gpg_key_ids,
                                 opt_gpg_homedir,
