@@ -28,6 +28,7 @@
 
 #include "flatpak-ref.h"
 #include "flatpak-builtins-utils.h"
+#include "flatpak-tty-utils-private.h"
 #include "flatpak-utils-private.h"
 #include "flatpak-run-private.h"
 
@@ -558,7 +559,6 @@ flatpak_resolve_matching_remotes (GPtrArray      *remote_dir_pairs,
                                   GError        **error)
 {
   guint chosen = 0; /* 1 indexed */
-  guint i;
 
   g_assert (remote_dir_pairs->len > 0);
 
@@ -567,34 +567,21 @@ flatpak_resolve_matching_remotes (GPtrArray      *remote_dir_pairs,
    * step after the dependencies are resolved.
    */
   if (remote_dir_pairs->len == 1)
-    chosen = 1;
-
-  if (chosen == 0)
     {
-      if (remote_dir_pairs->len == 1)
+      chosen = 1;
+    }
+  else
+    {
+      g_auto(GStrv) names = g_new0 (char *, remote_dir_pairs->len + 1);
+      for (guint i = 0; i < remote_dir_pairs->len; i++)
         {
-          RemoteDirPair *pair = g_ptr_array_index (remote_dir_pairs, 0);
-          const char *dir_name = flatpak_dir_get_name_cached (pair->dir);
-          if (flatpak_yes_no_prompt (TRUE, /* default to yes on Enter */
-                                     _("Found similar ref(s) for ‘%s’ in remote ‘%s’ (%s).\nUse this remote?"),
-                                     opt_search_ref, pair->remote_name, dir_name))
-            chosen = 1;
-          else
-            return flatpak_fail (error, _("No remote chosen to resolve matches for ‘%s’"), opt_search_ref);
-        }
-      else
-        {
-          g_auto(GStrv) names = g_new0 (char *, remote_dir_pairs->len + 1);
-          for (i = 0; i < remote_dir_pairs->len; i++)
-            {
-              RemoteDirPair *pair = g_ptr_array_index (remote_dir_pairs, i);
-              names[i] = g_strdup_printf ("‘%s’ (%s)", pair->remote_name, flatpak_dir_get_name_cached (pair->dir));
-            }
-          flatpak_format_choices ((const char **) names, _("Remotes found with refs similar to ‘%s’:"), opt_search_ref);
-          chosen = flatpak_number_prompt (TRUE, 0, remote_dir_pairs->len, _("Which do you want to use (0 to abort)?"));
-          if (chosen == 0)
-            return flatpak_fail (error, _("No remote chosen to resolve matches for ‘%s’"), opt_search_ref);
+          RemoteDirPair *pair = g_ptr_array_index (remote_dir_pairs, i);
+          names[i] = g_strdup_printf ("‘%s’ (%s)", pair->remote_name, flatpak_dir_get_name_cached (pair->dir));
         }
+      flatpak_format_choices ((const char **) names, _("Remotes found with refs similar to ‘%s’:"), opt_search_ref);
+      chosen = flatpak_number_prompt (TRUE, 0, remote_dir_pairs->len, _("Which do you want to use (0 to abort)?"));
+      if (chosen == 0)
+        return flatpak_fail (error, _("No remote chosen to resolve matches for ‘%s’"), opt_search_ref);
     }
 
   if (out_pair)
@@ -677,11 +664,11 @@ update_appstream (GPtrArray    *dirs,
               ts_file_age = get_appstream_timestamp (dir, remotes[i], arch);
               if (ts_file_age < ttl)
                 {
-                  g_debug ("%s:%s appstream age %" G_GUINT64_FORMAT " is less than ttl %" G_GUINT64_FORMAT, remotes[i], arch, ts_file_age, ttl);
+                  g_info ("%s:%s appstream age %" G_GUINT64_FORMAT " is less than ttl %" G_GUINT64_FORMAT, remotes[i], arch, ts_file_age, ttl);
                   continue;
                 }
               else
-                g_debug ("%s:%s appstream age %" G_GUINT64_FORMAT " is greater than ttl %" G_GUINT64_FORMAT, remotes[i], arch, ts_file_age, ttl);
+                g_info ("%s:%s appstream age %" G_GUINT64_FORMAT " is greater than ttl %" G_GUINT64_FORMAT, remotes[i], arch, ts_file_age, ttl);
 
               if (flatpak_dir_get_remote_disabled (dir, remotes[i]) ||
                   flatpak_dir_get_remote_noenumerate (dir, remotes[i]))
@@ -690,7 +677,7 @@ update_appstream (GPtrArray    *dirs,
               if (flatpak_dir_is_user (dir))
                 {
                   if (quiet)
-                    g_debug (_("Updating appstream data for user remote %s"), remotes[i]);
+                    g_info (_("Updating appstream data for user remote %s"), remotes[i]);
                   else
                     {
                       g_print (_("Updating appstream data for user remote %s"), remotes[i]);
@@ -700,7 +687,7 @@ update_appstream (GPtrArray    *dirs,
               else
                 {
                   if (quiet)
-                    g_debug (_("Updating appstream data for remote %s"), remotes[i]);
+                    g_info (_("Updating appstream data for remote %s"), remotes[i]);
                   else
                     {
                       g_print (_("Updating appstream data for remote %s"), remotes[i]);
@@ -711,7 +698,7 @@ update_appstream (GPtrArray    *dirs,
                                                  NULL, cancellable, &local_error))
                 {
                   if (quiet)
-                    g_debug ("%s: %s", _("Error updating"), local_error->message);
+                    g_info ("%s: %s", _("Error updating"), local_error->message);
                   else
                     g_printerr ("%s: %s\n", _("Error updating"), local_error->message);
                 }
@@ -735,11 +722,11 @@ update_appstream (GPtrArray    *dirs,
               ts_file_age = get_appstream_timestamp (dir, remote, arch);
               if (ts_file_age < ttl)
                 {
-                  g_debug ("%s:%s appstream age %" G_GUINT64_FORMAT " is less than ttl %" G_GUINT64_FORMAT, remote, arch, ts_file_age, ttl);
+                  g_info ("%s:%s appstream age %" G_GUINT64_FORMAT " is less than ttl %" G_GUINT64_FORMAT, remote, arch, ts_file_age, ttl);
                   continue;
                 }
               else
-                g_debug ("%s:%s appstream age %" G_GUINT64_FORMAT " is greater than ttl %" G_GUINT64_FORMAT, remote, arch, ts_file_age, ttl);
+                g_info ("%s:%s appstream age %" G_GUINT64_FORMAT " is greater than ttl %" G_GUINT64_FORMAT, remote, arch, ts_file_age, ttl);
 
               if (!flatpak_dir_update_appstream (dir, remote, arch, &changed,
                                                  NULL, cancellable, error))
