@@ -23,6 +23,7 @@
 #include <glib/gi18n.h>
 
 #include "flatpak-table-printer.h"
+#include "flatpak-tty-utils-private.h"
 #include "flatpak-utils-private.h"
 
 #include <string.h>
@@ -613,7 +614,7 @@ flatpak_table_printer_print_full (FlatpakTablePrinter *printer,
       for (i = 0; i < printer->columns->len && i < printer->n_columns; i++)
         {
           TableColumn *col = g_ptr_array_index (printer->columns, i);
-          char *title = col && col->title ? col->title : "";
+          const char *title = col && col->title ? col->title : "";
           gboolean expand = col ? col->expand : FALSE;
           gboolean ellipsize = col ? col->ellipsize : FALSE;
           int len = widths[i];
@@ -635,7 +636,7 @@ flatpak_table_printer_print_full (FlatpakTablePrinter *printer,
           if (shrinks[i] > 0 && ellipsize)
             {
               len -= shrinks[i];
-              freeme = title = ellipsize_string (title, len);
+              title = freeme = ellipsize_string (title, len);
             }
 
           if (i > 0)
@@ -716,7 +717,10 @@ flatpak_table_printer_print_full (FlatpakTablePrinter *printer,
 void
 flatpak_table_printer_print (FlatpakTablePrinter *printer)
 {
-  flatpak_table_printer_print_full (printer, 0, 80, NULL, NULL);
+  int rows, cols;
+
+  flatpak_get_window_size (&rows, &cols);
+  flatpak_table_printer_print_full (printer, 0, cols, NULL, NULL);
   g_print ("\n");
 }
 
