@@ -314,7 +314,7 @@ out:
   if (new_progress > 100)
     {
       if (!self->reported_overflow)
-        g_debug ("Unexpectedly got > 100%% progress, limiting");
+        g_info ("Unexpectedly got > 100%% progress, limiting");
       self->reported_overflow = TRUE;
       new_progress = 100;
     }
