@@ -39,6 +39,15 @@ void flatpak_http_session_free (FlatpakHttpSession* http_session);
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(FlatpakHttpSession, flatpak_http_session_free)
 
+typedef struct FlatpakCertificates FlatpakCertificates;
+
+FlatpakCertificates* flatpak_get_certificates_for_uri (const char *uri,
+                                                       GError    **error);
+FlatpakCertificates * flatpak_certificates_copy (FlatpakCertificates *other);
+void flatpak_certificates_free (FlatpakCertificates *certificates);
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(FlatpakCertificates, flatpak_certificates_free)
+
 typedef enum {
   FLATPAK_HTTP_FLAGS_NONE = 0,
   FLATPAK_HTTP_FLAGS_ACCEPT_OCI = 1 << 0,
@@ -52,6 +61,7 @@ typedef void (*FlatpakLoadUriProgress) (guint64  downloaded_bytes,
 
 GBytes * flatpak_load_uri_full (FlatpakHttpSession    *http_session,
                                 const char            *uri,
+                                FlatpakCertificates   *certificates,
                                 FlatpakHTTPFlags       flags,
                                 const char            *auth,
                                 const char            *token,
@@ -73,6 +83,7 @@ GBytes * flatpak_load_uri (FlatpakHttpSession    *http_session,
                            GError               **error);
 gboolean flatpak_download_http_uri (FlatpakHttpSession    *http_session,
                                     const char            *uri,
+                                    FlatpakCertificates   *certificates,
                                     FlatpakHTTPFlags       flags,
                                     GOutputStream         *out,
                                     const char            *token,
@@ -82,6 +93,7 @@ gboolean flatpak_download_http_uri (FlatpakHttpSession    *http_session,
                                     GError               **error);
 gboolean flatpak_cache_http_uri (FlatpakHttpSession    *http_session,
                                  const char            *uri,
+                                 FlatpakCertificates   *certificates,
                                  FlatpakHTTPFlags       flags,
                                  int                    dest_dfd,
                                  const char            *dest_subpath,
