@@ -32,6 +32,7 @@
 #include "flatpak-session-helper.h"
 #include "flatpak-utils-base-private.h"
 
+static GStrv original_environ = NULL;
 static char *monitor_dir;
 static char *p11_kit_server_socket_path;
 static int p11_kit_server_pid = 0;
@@ -101,7 +102,7 @@ child_watch_died (GPid     pid,
   PidData *pid_data = user_data;
   g_autoptr(GVariant) signal_variant = NULL;
 
-  g_debug ("Client Pid %d died", pid_data->pid);
+  g_info ("Client Pid %d died", pid_data->pid);
 
   signal_variant = g_variant_ref_sink (g_variant_new ("(uu)", pid, status));
   g_dbus_connection_emit_signal (session_bus,
@@ -188,8 +189,8 @@ child_setup_func (gpointer user_data)
           if (fd_map[i].from == data->tty)
             {
               if (ioctl (fd_map[i].final, TIOCSCTTY, 0) == -1)
-                g_debug ("ioctl(%d, TIOCSCTTY, 0) failed: %s",
-                         fd_map[i].final, strerror (errno));
+                g_info ("ioctl(%d, TIOCSCTTY, 0) failed: %s",
+                        fd_map[i].final, strerror (errno));
               break;
             }
         }
@@ -239,7 +240,7 @@ handle_host_command (FlatpakDevelopment    *object,
       return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
-  g_debug ("Running host command %s", arg_argv[0]);
+  g_info ("Running host command %s", arg_argv[0]);
 
   n_fds = 0;
   fds = NULL;
@@ -310,7 +311,7 @@ handle_host_command (FlatpakDevelopment    *object,
       env = g_strdupv (empty);
     }
   else
-    env = g_get_environ ();
+    env = g_strdupv (original_environ);
 
   n_envs = g_variant_n_children (arg_envs);
   for (i = 0; i < n_envs; i++)
@@ -354,7 +355,7 @@ handle_host_command (FlatpakDevelopment    *object,
                                                   pid_data,
                                                   NULL);
 
-  g_debug ("Client Pid is %d", pid_data->pid);
+  g_info ("Client Pid is %d", pid_data->pid);
 
   g_hash_table_replace (client_pid_data_hash, GUINT_TO_POINTER (pid_data->pid),
                         pid_data);
@@ -384,7 +385,7 @@ handle_host_command_signal (FlatpakDevelopment    *object,
       return G_DBUS_METHOD_INVOCATION_HANDLED;
     }
 
-  g_debug ("Sending signal %d to client pid %d", arg_signal, arg_pid);
+  g_info ("Sending signal %d to client pid %d", arg_signal, arg_pid);
 
   if (to_process_group)
     killpg (pid_data->pid, arg_signal);
@@ -566,8 +567,8 @@ update_real_monitor (MonitorData *data)
 
   if (real == NULL)
     {
-      g_debug ("unable to get real path to monitor host file %s: %s", data->source,
-               g_strerror (errno));
+      g_info ("unable to get real path to monitor host file %s: %s", data->source,
+              g_strerror (errno));
       return;
     }
 
@@ -606,7 +607,7 @@ update_real_monitor (MonitorData *data)
   data->monitor_real = g_file_monitor_file (r, G_FILE_MONITOR_NONE, NULL, &err);
   if (!data->monitor_real)
     {
-      g_debug ("failed to monitor host file %s (real path of %s): %s",
+      g_info ("failed to monitor host file %s (real path of %s): %s",
                real, data->source, err->message);
       return;
     }
@@ -625,7 +626,7 @@ file_monitor_do (MonitorData *data)
       /* We can't update the /etc/localtime symlink at runtime, nor can we make it a of the
        * correct form "../usr/share/zoneinfo/$timezone". So, instead we use the old debian
        * /etc/timezone file for telling the sandbox the timezone. */
-      char *dest = g_build_filename (monitor_dir, "timezone", NULL);
+      g_autofree char *dest = g_build_filename (monitor_dir, "timezone", NULL);
       g_autofree char *raw_timezone = flatpak_get_timezone ();
       g_autofree char *timezone_content = g_strdup_printf ("%s\n", raw_timezone);
 
@@ -665,7 +666,7 @@ setup_file_monitor (const char *source)
     }
   else
     {
-      g_debug ("failed to monitor host file %s: %s", source, err->message);
+      g_info ("failed to monitor host file %s: %s", source, err->message);
     }
 
   file_monitor_do (data);
@@ -680,7 +681,7 @@ message_handler (const gchar   *log_domain,
                  gpointer       user_data)
 {
   /* Make this look like normal console output */
-  if (log_level & G_LOG_LEVEL_DEBUG)
+  if (log_level & (G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO))
     g_printerr ("F: %s\n", message);
   else
     g_printerr ("%s: %s\n", g_get_prgname (), message);
@@ -696,7 +697,7 @@ start_p11_kit_server (const char *flatpak_dir)
   g_autoptr(GError) local_error = NULL;
   g_auto(GStrv) stdout_lines = NULL;
   int i;
-  char *p11_argv[] = {
+  const char * const p11_argv[] = {
     "p11-kit", "server",
     /* We explicitly request --sh here, because we then fail on earlier versions that doesn't support
      * this flag. This is good, because those earlier versions did not properly daemonize and caused
@@ -709,10 +710,11 @@ start_p11_kit_server (const char *flatpak_dir)
     NULL
   };
 
-  g_debug ("starting p11-kit server");
+  g_info ("starting p11-kit server");
 
   if (!g_spawn_sync (NULL,
-                     p11_argv, NULL, G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
+                     (char **) p11_argv, NULL,
+                     G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
                      NULL, NULL,
                      &p11_kit_stdout, NULL,
                      &exit_status, &local_error))
@@ -750,11 +752,11 @@ start_p11_kit_server (const char *flatpak_dir)
 
   if (p11_kit_server_pid != 0)
     {
-      g_debug ("Using p11-kit socket path %s, pid %d", socket_path, p11_kit_server_pid);
+      g_info ("Using p11-kit socket path %s, pid %d", socket_path, p11_kit_server_pid);
       p11_kit_server_socket_path = g_steal_pointer (&socket_path);
     }
   else
-    g_debug ("Not using p11-kit due to older version");
+    g_info ("Not using p11-kit due to older version");
 }
 
 int
@@ -766,8 +768,9 @@ main (int    argc,
   gboolean replace;
   gboolean verbose;
   gboolean show_version;
-  GOptionContext *context;
+  g_autoptr(GOptionContext) context = NULL;
   GBusNameOwnerFlags flags;
+  g_autofree char *pk11_program = NULL;
   g_autofree char *flatpak_dir = NULL;
   g_autoptr(GError) error = NULL;
   const GOptionEntry options[] = {
@@ -783,6 +786,10 @@ main (int    argc,
                          m_localtime = NULL;
   struct sigaction action;
 
+  /* Save the enviroment before changing anything, so that subprocesses
+   * can get the unchanged version */
+  original_environ = g_get_environ ();
+
   atexit (do_atexit);
 
   memset (&action, 0, sizeof (struct sigaction));
@@ -815,10 +822,11 @@ main (int    argc,
       g_printerr ("Try \"%s --help\" for more information.",
                   g_get_prgname ());
       g_printerr ("\n");
-      g_option_context_free (context);
       return 1;
     }
 
+  g_clear_pointer (&context, g_option_context_free);
+
   if (show_version)
     {
       g_print (PACKAGE_STRING "\n");
@@ -826,7 +834,7 @@ main (int    argc,
     }
 
   if (verbose)
-    g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, message_handler, NULL);
+    g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_INFO, message_handler, NULL);
 
   client_pid_data_hash = g_hash_table_new_full (NULL, NULL, NULL, (GDestroyNotify) pid_data_free);
 
@@ -844,10 +852,11 @@ main (int    argc,
       exit (1);
     }
 
-  if (g_find_program_in_path ("p11-kit"))
+  pk11_program = g_find_program_in_path ("p11-kit");
+  if (pk11_program)
     start_p11_kit_server (flatpak_dir);
   else
-    g_debug ("p11-kit not found");
+    g_info ("p11-kit not found");
 
   monitor_dir = g_build_filename (flatpak_dir, "monitor", NULL);
   if (g_mkdir_with_parents (monitor_dir, 0755) != 0)
@@ -880,5 +889,6 @@ main (int    argc,
 
   g_bus_unown_name (owner_id);
 
+  g_strfreev (original_environ);
   return 0;
 }
