@@ -114,6 +114,20 @@ ObjectPath=/org/test/Hello/SearchProvider
 Version=2
 EOF
 
+mkdir -p ${DIR}/files/share/krunner/dbusplugins
+cat > ${DIR}/files/share/krunner/dbusplugins/org.test.Hello.desktop <<EOF
+[Desktop Entry]
+Name=Hello
+X-KDE-ServiceTypes=Plasma/Runner
+Type=Service
+Icon=org.test.Hello
+X-KDE-ServiceTypes=Plasma/Runner
+X-KDE-PluginInfo-EnabledByDefault=true
+X-Plasma-API=DBus
+X-Plasma-DBusRunner-Service=org.test.Hello.KRunner
+X-Plasma-DBusRunner-Path=/org/test/Hello/KRunner
+EOF
+
 mkdir -p ${DIR}/files/share/icons/hicolor/64x64/apps
 cp $(dirname $0)/org.test.Hello.png ${DIR}/files/share/icons/hicolor/64x64/apps/${APP_ID}.png
 cp $(dirname $0)/org.test.Hello.png ${DIR}/files/share/icons/hicolor/64x64/apps/dont-export.png
@@ -174,9 +188,9 @@ fi
 
 mkdir -p ${DIR}/files/share/locale
 mkdir -p ${DIR}/files/share/runtime/locale/de
-ln -s -t ${DIR}/files/share/locale ../../share/runtime/locale/de/share/de
+ln -s ../../share/runtime/locale/de/share/de ${DIR}/files/share/locale
 mkdir -p ${DIR}/files/share/runtime/locale/fr
-ln -s -t ${DIR}/files/share/locale ../../share/runtime/locale/fr/share/fr
+ln -s ../../share/runtime/locale/fr/share/fr ${DIR}/files/share/locale
 
 flatpak build-finish ${BUILD_FINISH_ARGS-} --command=hello.sh ${DIR} >&2
 mkdir -p repos
